var args = arguments[0] || {},
		cameraOverlay = null,
		cameraImage = null,
		currentIntent = null,
		utility = require('utility'),
		buttonLock = false,
		errorHandler = require('errorHandler/errorHandler');

function retakeImagePressed() {
	if (!buttonLock) {
		removeEventListeners();
		openCamera();
	}
}	

function saveImagePressed() {

	if (!buttonLock) {
		removeEventListeners();
		cameraImage = utility.rotateImage(cameraImage, -90);

		args.saveImage.call(null, null, cameraImage);

		$.cameraScreen.close();
	}
	
}

function cancelPressed() {
	$.cameraScreen.close();
}

function init() {
	$.previewContainer.hide();
	
	cameraOverlay = Alloy.createController("cameraOverlay", {
		cancel: cancelPressed,
	});

	$.cameraScreen.addEventListener('open', windowOpened);
	$.cameraScreen.addEventListener('close', windowClosed);

	removeEventListeners();	
}

function windowOpened() {
	openCamera();
}

function windowClosed() {
	cameraImage = null;
}

function openCamera() {
	cameraOverlay.enableButtons();
	cameraOverlay.setChequeDirection();

	var overlayView = null;
	
	if (Alloy.isTablet) {
		if (OS_IOS && Ti.Gesture.isPortrait()) {
			overlayView = cameraOverlay.getVerticalLayout();
		} else {
			overlayView = cameraOverlay.getHorizontalLayout();
		}
	} else {
		overlayView = cameraOverlay.getVerticalLayout();
	}

	Ti.Media.showCamera({
		success: function(event) {
			if(event.mediaType == Ti.Media.MEDIA_TYPE_PHOTO) {		

				$.previewContainer.show();
				$.loadingContainer.show();
				Ti.Media.hideCamera();

				cameraImage = utility.resizeImage(event.media);
				
				// Rotate if image is landscape orientation
				if (Alloy.isHandheld && cameraImage.height < cameraImage.width) {
					cameraImage = utility.rotateImage(cameraImage, 90);
				} else if (Alloy.isTablet && cameraImage.height > cameraImage.width) {
					cameraImage = utility.rotateImage(cameraImage, 90);
				}
				
				$.previewImage.applyProperties($.createStyle({
				  image: cameraImage,
				}));

				addEventListeners();
				
				$.loadingContainer.hide();
			}
		},
		cancel: function() {
			cancelPressed();
		},
		error: function(error) {
			Ti.Media.hideCamera();
			$.cameraScreen.close();

			var AlertModal = require('modals/alert-modal');
			var errorModal = AlertModal.create({
				message: "Something went wrong. Please try again",
			});
			errorModal.open();
		},
		overlay: overlayView,
		mediaTypes:  Ti.Media.MEDIA_TYPE_PHOTO,
		showControls: false,
		autohide: false,
		allowImageEditing: false,
		autorotate: false,
		animated: false,
	});
}

function addEventListeners() {
	buttonLock = false;
}

function removeEventListeners() {
	buttonLock = true;
}

exports.open = function(intent) {
	currentIntent = intent;
	var permission = false;
	
	if(!Titanium.Media.hasCameraPermissions()){
		Titanium.Media.requestCameraPermissions(function(e){
			if(e.success){
				$.cameraScreen.open();
			}else{
				errorHandler.showError(errorHandler.errorTypes.cameraNotAuthorized);
			}
		});
	}else{
		$.cameraScreen.open();
	}
	
};

exports.cleanup = function() {

	$.cameraScreen.removeEventListener('open', windowOpened);
	$.cameraScreen.removeEventListener('close', windowClosed);
};

init();